@@ -1,18 +1,17 @@
-# aclint: py3
 import asyncio
 import copy
 import logging
-import re
 import os
+import re
 import tempfile
-
 from dataclasses import dataclass
-from typing import List, Pattern, Tuple, Optional, Dict, Any
+from typing import Any, Dict, List, Optional, Pattern, Tuple
+
 from revup import shell
 from revup.types import (
     GitCommitHash,
-    GitTreeHash,
     GitConflictException,
+    GitTreeHash,
     RevupUsageException,
 )
 
@@ -33,7 +32,8 @@ RE_LS_FILES_LINE = re.compile(
     r"^[0-9]+ (?P<hash>[0-9a-f]+) (?P<stage>[0-9])\t(?P<path>.*)$", re.MULTILINE
 )
 RE_RAW_DIFF_TREE_LINE = re.compile(
-    r"^:(?P<old_mode>[0-9]+) (?P<new_mode>[0-9]+) (?P<old_hash>[0-9a-f]+) (?P<new_hash>[0-9a-f]+) (?P<type>[a-zA-Z]+)\t(?P<path>.*)$",
+    r"^:(?P<old_mode>[0-9]+) (?P<new_mode>[0-9]+) (?P<old_hash>[0-9a-f]+) (?P<new_hash>[0-9a-f]+)"
+    r" (?P<type>[a-zA-Z]+)\t(?P<path>.*)$",
     re.MULTILINE,
 )
 
@@ -69,13 +69,6 @@ class CommitHeader:
     commit_id: GitCommitHash = GitCommitHash("")
 
 
-@dataclass
-class MergeResult(object):
-    path: str
-    conflict: bool
-    rerere_fixed: bool
-
-
 def parse_commit_header(raw_header: str) -> CommitHeader:
     def _search_group(raw_header: str, regex: Pattern[str], group: str) -> str:
         m = regex.search(raw_header)
@@ -148,7 +141,6 @@ async def make_git(
     main_branch: str = "",
     base_branch_globs: str = "",
     keep_temp: bool = False,
-    author: str = "",
     editor: str = "",
 ) -> "Git":
     if not git_path:
@@ -195,12 +187,12 @@ async def make_git(
     sh.cwd = git_ctx.repo_root
     git_ctx.git_dir = git_dir
     git_ctx.email = email.lower()
-    git_ctx.author = author if author else git_ctx.email.split("@")[0]
+    git_ctx.author = git_ctx.email.split("@")[0]
     git_ctx.editor = editor
     return git_ctx
 
 
-class Git(object):
+class Git:
     # Shell object to run git with
     sh: shell.Shell
 
@@ -246,7 +238,9 @@ class Git(object):
         self.keep_temp = keep_temp
         self.main_branch = main_branch
         self.base_branch_globs = base_branch_globs.strip().splitlines()
-        self.temp_dir = tempfile.TemporaryDirectory(prefix="revup_")
+        self.temp_dir = tempfile.TemporaryDirectory(  # pylint: disable=consider-using-with
+            prefix="revup_"
+        )
         if self.keep_temp:
             os.makedirs(self.get_scratch_dir(), exist_ok=True)
 
@@ -302,8 +296,11 @@ class Git(object):
             rev_list_args.extend(["--not", exclude])
         return await self.git_stdout(*rev_list_args)
 
+    async def is_branch_or_commit(self, obj: str) -> bool:
+        return await self.git_return_code("rev-parse", "--verify", "--quiet", obj) == 0
+
     async def verify_branch_or_commit(self, obj: str) -> None:
-        if await self.git_return_code("rev-parse", "--verify", "--quiet", obj):
+        if not await self.is_branch_or_commit(obj):
             raise RevupUsageException(f"{obj} is not a commit or branch name!")
 
     async def commit_exists(self, obj: str) -> bool:
@@ -515,7 +512,7 @@ class Git(object):
         commit: GitCommitHash,
     ) -> str:
         """
-        Return the patch-id that uniquely identifies this commit's diff (but not its other metadata).
+        Return a patch-id that uniquely identifies this commit's diff (but not its other metadata).
         """
         patch_source = (
             [
@@ -695,29 +692,3 @@ class Git(object):
         )
 
         return await self.commit_tree(new_commit_info)
-
-    async def merge(
-        self, commit: GitCommitHash, commit_msg: str, skip: bool = False, strategy: str = ""
-    ) -> List[MergeResult]:
-        merge_args = [
-            "-c",
-            "merge.verbosity=0",
-            "merge",
-            "--no-ff",
-            "--no-commit",
-            "--no-verify",
-            "--quiet",
-        ]
-        if skip:
-            merge_args.extend(["-s", "ours"])
-
-        if strategy:
-            merge_args.append("-X" + strategy)
-
-        merge_args.append(commit)
-        await self.git(*merge_args, raiseonerror=False)
-
-        ret = []
-
-        await self.git("commit", "--allow-empty", "-n", "-a", "-m", commit_msg)
-        return ret
