@@ -1,12 +1,9 @@
-# aclint: py3
-import re
 import logging
-from typing import Optional, NamedTuple, Set, List, Tuple, Dict, Any, Iterable
+import re
 from dataclasses import dataclass, field
+from typing import Any, Dict, Iterable, List, NamedTuple, Optional, Set, Tuple
 
-
-from revup import github
-from revup import git
+from revup import git, github
 from revup.types import GitCommitHash
 
 GitHubRepoInfo = NamedTuple(
@@ -141,8 +138,8 @@ async def query_everything(
     str, List[Optional[PrInfo]], Dict[str, str], Dict[str, str], Dict[str, str]
 ]:  # pylint: disable=too-many-statements, too-many-locals
     """
-    This function does all necessary graphql querying in one request. This dramatically reduces the amount
-    of time spent on querying.
+    This function does all necessary graphql querying in one request. This dramatically reduces the
+    amount of time spent on querying.
 
     Returns a tuple of:
     - Repository node id
@@ -172,34 +169,20 @@ async def query_everything(
     request_str = "".join(
         len(head_refs)
         * [
-            """
-                {}: pullRequests (headRefName: ${}, states: [OPEN, MERGED], first: 1, orderBy: {{direction: DESC, field:UPDATED_AT}}) {{
-                    ...PrResult
-                }},"""
+            "{}: pullRequests (headRefName: ${}, states: [OPEN, MERGED], first: 1, "
+            "orderBy: {{direction: DESC, field:UPDATED_AT}}) {{"
+            "...PrResult"
+            "}},"
         ]
     )
     request_str = request_str.format(*zip_and_flatten(prs_out, head_refs_args.keys()))
 
     user_str = "".join(
-        len(user_ids)
-        * [
-            """
-                {}: assignableUsers (query: ${}, first: 25) {{
-                    ...UserResult
-                }},"""
-        ]
+        len(user_ids) * ["{}: assignableUsers (query: ${}, first: 25) {{...UserResult}},"]
     )
     user_str = user_str.format(*zip_and_flatten(user_id_out, user_id_args.keys()))
 
-    label_str = "".join(
-        len(labels)
-        * [
-            """
-                {}: label (name: ${}) {{
-                    ...LabelResult
-                }},"""
-        ]
-    )
+    label_str = "".join(len(labels) * ["{}: label (name: ${}) {{...LabelResult}},"])
     label_str = label_str.format(*zip_and_flatten(label_out, label_args.keys()))
 
     multi_query_str = f"""
@@ -303,7 +286,7 @@ async def query_everything(
     )
 
     prs: List[Optional[PrInfo]] = []
-    for i in range(len(head_refs)):
+    for i, branch_name in enumerate(head_refs):
         this_node = pr_result["data"]["repository"][prs_out[i]]
         if len(this_node["nodes"]) == 1:
             this_node = this_node["nodes"][0]
@@ -346,7 +329,7 @@ async def query_everything(
                     id=this_node["id"],
                     url=this_node["url"],
                     baseRef=this_node["baseRefName"],
-                    headRef=head_refs[i],
+                    headRef=branch_name,
                     baseRefOid=baseRefOid,
                     headRefOid=headRefOid,
                     body=this_node["body"],
@@ -367,28 +350,28 @@ async def query_everything(
 
     names_to_ids = {}
     names_to_logins = {}
-    for i in range(len(user_ids)):
+    for i, user_id in enumerate(user_ids):
         this_node = pr_result["data"]["repository"][user_id_out[i]]
         if len(this_node["nodes"]) == 0:
-            logging.warning("No matching user found for {}".format(user_ids[i]))
+            logging.warning("No matching user found for {}".format(user_id))
         elif this_node["totalCount"] > len(this_node["nodes"]):
-            logging.warning("Too many matching users found for {}".format(user_ids[i]))
+            logging.warning("Too many matching users found for {}".format(user_id))
         else:
             shortest_name = this_node["nodes"][0]["login"]
-            names_to_ids[user_ids[i]] = this_node["nodes"][0]["id"]
+            names_to_ids[user_id] = this_node["nodes"][0]["id"]
             for user in this_node["nodes"]:
                 if len(user["login"]) <= len(shortest_name):
                     shortest_name = user["login"]
-                    names_to_ids[user_ids[i]] = user["id"]
-                    names_to_logins[user_ids[i]] = user["login"]
+                    names_to_ids[user_id] = user["id"]
+                    names_to_logins[user_id] = user["login"]
 
     labels_to_ids = {}
-    for i in range(len(labels)):
+    for i, label in enumerate(labels):
         this_node = pr_result["data"]["repository"][label_out[i]]
         if this_node is not None:
-            labels_to_ids[labels[i]] = this_node["id"]
+            labels_to_ids[label] = this_node["id"]
         else:
-            logging.warning("Couldn't find an existing label named {}".format(labels[i]))
+            logging.warning("Couldn't find an existing label named {}".format(label))
 
     return (
         pr_result["data"]["repository"]["id"],
@@ -444,11 +427,11 @@ async def create_pull_requests(
 
     # Creating a pull request can fail if the branch is already merged.
     pr_results = await github_ep.graphql(mutation_str, require_success=False, **inputs_args)
-    for i in range(len(prs)):
+    for i, pr in enumerate(prs):
         result = pr_results["data"][prs_out[i]]["pullRequest"]
         if result is not None:
-            prs[i].id = result["id"]
-            prs[i].url = result["url"]
+            pr.id = result["id"]
+            pr.url = result["url"]
 
 
 async def update_pull_requests(  # pylint: disable=too-many-locals,too-many-statements
