@@ -1,27 +1,25 @@
-# aclint: py3
 # pylint: disable=too-many-lines
 from __future__ import annotations
 
 import logging
 import re
-from collections import defaultdict
-from typing import List, Set, Dict, Optional, Tuple, Iterator
-from dataclasses import dataclass, field
-from enum import Enum
-from rich.markup import escape
-from rich import get_console
-from datetime import datetime
 import subprocess
+from collections import defaultdict
+from dataclasses import dataclass, field
+from datetime import datetime
+from enum import Enum
+from typing import Dict, Iterator, List, Optional, Set, Tuple
 
-from revup import git
-from revup import github
-from revup import github_utils
-from revup.github_utils import PrInfo, PrUpdate, PrComment
+from rich import get_console
+from rich.markup import escape
+
+from revup import git, github, github_utils
+from revup.github_utils import PrComment, PrInfo, PrUpdate
 from revup.types import (
     GitCommitHash,
-    RevupUsageException,
     GitConflictException,
     RevupConflictException,
+    RevupUsageException,
 )
 
 
@@ -78,17 +76,17 @@ def translate_if_exists(names: Set[str], translation: Dict[str, str]) -> Set[str
 
 # The current state of each review within github.
 class PrStatus(Enum):
-    NEW = "new"
-    UPDATED = "updated"
-    NOCHANGE = "no change"
-    MERGED = "already merged"
+    NEW = "new"  # needs to be created, or was just created
+    UPDATED = "updated"  # github data needs to be modified (title, reviewers, labels, etc)
+    NOCHANGE = "no change"  # no github mutations are necessary
+    MERGED = "already merged"  # change has already merged (and no mutations are possible)
 
 
 # The status of the git branch
 class PushStatus(Enum):
-    PUSHED = "pushed"
-    REBASE = "rebase"
-    NOCHANGE = "no change"
+    PUSHED = "pushed"  # commit hash for the branch changed and will or has been pushed
+    REBASE = "rebase"  # branch is not being pushed because it is a rebase
+    NOCHANGE = "no change"  # branch is not being pushed because it has not changed at all
 
 
 @dataclass
@@ -111,7 +109,7 @@ class Review:  # pylint: disable=too-many-instance-attributes
     # Name for the remote head ref. Will be based on topic name + base branch
     remote_head: str = ""
 
-    # Name for the remote base ref. One of a remote base branch / relative branch / another topic's remote_head
+    # Name for the remote base ref. One of a base branch / relative branch / another topic's head
     remote_base: str = ""
 
     # Name of a relative branch if it exists
@@ -191,9 +189,6 @@ class TopicStack:
     # Branch / review that current reviews are relative to
     relative_branch: str
 
-    # Uploader name used to format remote branch names
-    uploader: str
-
     # Github access info
     github_ep: Optional[github.GitHubEndpoint] = None
     repo_info: Optional[github_utils.GitHubRepoInfo] = None
@@ -261,7 +256,7 @@ class TopicStack:
                     tag = tag[:-1]
             val.discard("")  # Discards any whitespace only values, since it was stripped prior
             if tag in VALID_TAGS:
-                if tag == TAG_BRANCH or tag == TAG_RELATIVE_BRANCH:
+                if tag in (TAG_BRANCH, TAG_RELATIVE_BRANCH):
                     val = set(self.git_ctx.ensure_branch_prefix(b) for b in val)
                 ret[tag].update(val)
             else:
@@ -336,19 +331,13 @@ class TopicStack:
         )
         return PrComment(ret, orig.id if orig else None)
 
-    async def populate_topics(  # pylint: disable=too-many-branches, too-many-statements, too-many-locals
+    async def populate_topics(
         self,
-        force_relative_chain: bool,
-        auto_topic: bool,
+        auto_topic: bool = False,
         trim_tags: bool = False,
-        labels: str = None,
-        user_aliases: str = "",
-        auto_add_users: str = "",
-        self_authored_only: bool = False,
     ) -> None:
         """
-        Parse all commits and sort them into individual topics and reviews.
-        Verify base branch and relative topic info to ensure it is valid.
+        Parse all commits and sort them into individual topics.
         """
         if self.base_branch:
             self.base_branch = self.git_ctx.ensure_branch_prefix(self.base_branch)
@@ -415,6 +404,19 @@ class TopicStack:
         if len(self.topics) == 0:
             raise RevupUsageException(f"Found {len(self.commits)} commits but no topic tags!")
 
+    async def populate_reviews(  # pylint: disable=too-many-branches, too-many-statements, too-many-locals
+        self,
+        uploader: str,
+        force_relative_chain: bool = False,
+        labels: str = None,
+        user_aliases: str = "",
+        auto_add_users: str = "",
+        self_authored_only: bool = False,
+    ) -> None:
+        """
+        Populate reviews for already-parsed topics. Verify base branch and relative topic info to
+        ensure it is valid.
+        """
         seen_topics: Dict[str, Topic] = {}
         for name, topic in list(self.topics.items()):
             relative_topic = ""
@@ -427,6 +429,10 @@ class TopicStack:
                     if c.author_email.lower() == self.git_ctx.email:
                         has_self_authored = True
                 if not has_self_authored:
+                    logging.info(
+                        f"Skipping topic '{name}' since it has no self-authored commits,"
+                        " pass '--no-self-authored-only' to override"
+                    )
                     del self.topics[name]
                     continue
 
@@ -457,7 +463,8 @@ class TopicStack:
                         )
                     else:
                         logging.warning(
-                            f"Relative topic '{relative_topic}' not found in stack, assuming it was merged"
+                            f"Relative topic '{relative_topic}' not found in stack, assuming it was"
+                            " merged"
                         )
                         relative_topic = ""
 
@@ -524,9 +531,7 @@ class TopicStack:
                     f" {relative_topic} has uploader"
                     f" {topic.relative_topic.tags[TAG_UPLOADER] or '{}'}"
                 )
-            topic_uploader = (
-                min(topic.tags[TAG_UPLOADER]) if topic.tags[TAG_UPLOADER] else self.uploader
-            )
+            topic_uploader = min(topic.tags[TAG_UPLOADER]) if topic.tags[TAG_UPLOADER] else uploader
 
             for c in topic.original_commits:
                 m = RE_COMMIT_LABEL.match(c.commit_msg)
@@ -563,7 +568,7 @@ class TopicStack:
                     topic.relative_topic.reviews[branch].children.append(review)
 
                     review.remote_base = topic.relative_topic.reviews[branch].remote_head
-                    # Base ref is empty since it doesn't exist yet. It will get populated in create_commits()
+                    # Base ref is empty since it doesn't exist until create_commits()
                 else:
                     if relative_branch == self.relative_branch:
                         review.base_ref = self.commits[0].parents[0]
@@ -580,9 +585,9 @@ class TopicStack:
             # Don't add draft as a label since its instead used to mark a pr as a draft
             topic.tags[TAG_LABEL].discard("draft")
 
-            if auto_add_users == "r2a" or auto_add_users == "both":
+            if auto_add_users in ("r2a", "both"):
                 topic.tags[TAG_ASSIGNEE].update(topic.tags[TAG_REVIEWER])
-            if auto_add_users == "a2r" or auto_add_users == "both":
+            if auto_add_users in ("a2r", "both"):
                 topic.tags[TAG_REVIEWER].update(topic.tags[TAG_ASSIGNEE])
 
             seen_topics[name] = topic
@@ -767,7 +772,7 @@ class TopicStack:
                     else:
                         break
 
-    async def create_commits(self, no_cherry_pick: bool, trim_tags: bool) -> None:
+    async def create_commits(self, trim_tags: bool) -> None:
         """
         Populate new_commits for all reviews by cherry-picking to the base ref if necessary.
         """
@@ -796,11 +801,6 @@ class TopicStack:
                     review.new_commits.append(commit.commit_id)
                     next_parent = commit.commit_id
                 else:
-                    if no_cherry_pick:
-                        raise RevupUsageException(
-                            f"Would require cherry picking {commit.commit_id} to"
-                            f" {next_parent} since its actual parent is {commit.parents[0]}"
-                        )
                     # TODO: Potential optimization here: if remote_base_oid and base_ref are
                     # the same, we can use trees to pick the first N commits where patch-id
                     # is equal to remote patch-id
@@ -809,7 +809,7 @@ class TopicStack:
                         next_parent = await self.git_ctx.synthetic_cherry_pick_from_commit(
                             commit, next_parent
                         )
-                    except GitConflictException:
+                    except GitConflictException as exc:
                         parent_info = (
                             "the same topic"
                             if next_parent != review.base_ref
@@ -822,7 +822,7 @@ class TopicStack:
                             f'"{commit.title}" ({commit.commit_id[:8]}) in topic "{name}"\n'
                             f"to new parent ({next_parent[:8]}) in {parent_info}\n\n"
                             "You must specify relative branches to prevent this conflict!"
-                        )
+                        ) from exc
                     review.new_commits.append(next_parent)
 
             if review.pr_info is not None and review.pr_info.headRefOid == review.new_commits[-1]:
@@ -871,7 +871,7 @@ class TopicStack:
             ]
             await self.git_ctx.git(*fetch_args)
 
-    async def push_git_refs(self, create_local_branches: bool) -> None:
+    async def push_git_refs(self, uploader: str, create_local_branches: bool) -> None:
         """
         Push all refs to their branch on the remote.
         """
@@ -895,7 +895,7 @@ class TopicStack:
                 )
 
         if self.last_virtual_diff_target is not None:
-            virtual_diff_branch = f"{self.uploader}/revup/virtual_diff_targets"
+            virtual_diff_branch = f"{uploader}/revup/virtual_diff_targets"
             push_targets.append(f"{self.last_virtual_diff_target}:refs/heads/{virtual_diff_branch}")
 
         # It's much faster to push all refs in one command
@@ -984,7 +984,8 @@ class TopicStack:
                 if review.status == PrStatus.NEW:
                     if not review.base_ref:
                         raise RuntimeError(
-                            f"Bug! review {review.topic.name} {review.remote_base} doesn't have a base ref"
+                            f"Bug! review {review.topic.name} {review.remote_base} doesn't have a"
+                            " base ref"
                         )
                     review.pr_info = PrInfo(
                         baseRef=review.remote_base,
@@ -1014,7 +1015,7 @@ class TopicStack:
                 labels = set(topic.tags[TAG_LABEL])
                 base_branch_name = self.git_ctx.remove_branch_prefix(branch)
                 if base_branch_name in self.labels_to_ids:
-                    # Add the base branch as a tag so it can be used to see pending changes on that branch.
+                    # Add the base branch name as a tag which can show all changes on that branch
                     labels.add(base_branch_name)
 
                 label_ids = translate_if_exists(labels, self.labels_to_ids).difference(
@@ -1067,10 +1068,10 @@ class TopicStack:
             review_title = review.pr_update.title or review.pr_info.title
             num_nodes = 1
             ret[review.remote_head][0] += f"{back}{prefix}{review.pr_info.url} {review_title}\n"
-            for i in range(len(review.children)):
-                ret[review.children[i].remote_head] = ret[review.remote_head]
+            for i, child in enumerate(review.children):
+                ret[child.remote_head] = ret[review.remote_head]
                 num_nodes += graph_helper(
-                    review.children[i],
+                    child,
                     back + ("\u3000" if prefix == "└" else "│"),
                     ("└" if i == len(review.children) - 1 else "├"),
                 )
@@ -1159,7 +1160,7 @@ class TopicStack:
             if not review.pr_info:
                 continue
             if (
-                review.pr_update.baseRef is not None
+                review.pr_update.baseRef is not None  # pylint: disable=too-many-boolean-expressions
                 or review.pr_update.body is not None
                 or review.pr_update.title is not None
                 or review.pr_update.reviewer_ids
@@ -1210,13 +1211,13 @@ class TopicStack:
                 new_parent = await self.git_ctx.synthetic_cherry_pick_from_commit(
                     commit, new_parent
                 )
-            except GitConflictException:
+            except GitConflictException as exc:
                 raise RevupConflictException(
                     "Failed to cherry-pick commit:\n"
                     f'"{commit.title}" ({commit.commit_id[:8]})\n'
                     f"to new parent ({new_parent[:8]})\n\n"
                     f"You may need to `git rebase -i {new_parent[:8]}` to resolve these conflicts!"
-                )
+                ) from exc
         git_env = {
             "GIT_REFLOG_ACTION": "reset --soft (revup restack)",
         }
@@ -1233,8 +1234,9 @@ class TopicStack:
         for _, topic in reversed(self.topics.items()):
             for _, review in topic.reviews.items():
                 if (
-                    review.status == PrStatus.NOCHANGE or review.status == PrStatus.MERGED
-                ) and review.push_status != PushStatus.PUSHED:
+                    review.status in (PrStatus.NOCHANGE, PrStatus.MERGED)
+                    and review.push_status != PushStatus.PUSHED
+                ):
                     continue
                 ret += 1
         return ret
